==> haskell-base-compat-batteries-0.10.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-compat-batteries.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-compat-batteries
version: 0.10.1
id: base-compat-batteries-0.10.1-LG7t1c0cCz36PTZWZEdTpV
key: base-compat-batteries-0.10.1-LG7t1c0cCz36PTZWZEdTpV
license: MIT
copyright: (c) 2012-2018 Simon Hengel,
           (c) 2014-2018 João Cristóvão,
           (c) 2015-2018 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
synopsis: base-compat with extra batteries
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.
    .
    This package provides the same API as the
    @<http://hackage.haskell.org/package/base-compat base-compat>@
    library, but depends on compatibility packages
    (such as @semigroups@) to offer a wider support window than
    @base-compat@, which has no dependencies. Most of the modules
    in this library have the same names as in @base-compat@
    to make it easier to switch between the two. There also exist
    versions of each module with the suffix @.Repl.Batteries@,
    which are distinct from anything in @base-compat@, to allow
    for easier use in GHCi.
    .
    See
    @<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown#dependencies here>@
    for a more comprehensive list of differences between
    @base-compat@ and @base-compat-batteries@.
category: Compatibility
abi: ecc4267054473a41b73764a289bc4bdf
exposed: True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.Compat.Repl.Batteries
    Control.Concurrent.MVar.Compat
    Control.Concurrent.MVar.Compat.Repl.Batteries Control.Monad.Compat
    Control.Monad.Compat.Repl.Batteries Control.Monad.Fail.Compat
    Control.Monad.Fail.Compat.Repl.Batteries
    Control.Monad.IO.Class.Compat
    Control.Monad.IO.Class.Compat.Repl.Batteries
    Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Lazy.Unsafe.Compat.Repl.Batteries
    Control.Monad.ST.Unsafe.Compat
    Control.Monad.ST.Unsafe.Compat.Repl.Batteries
    Data.Bifoldable.Compat Data.Bifoldable.Compat.Repl.Batteries
    Data.Bifunctor.Compat Data.Bifunctor.Compat.Repl.Batteries
    Data.Bitraversable.Compat Data.Bitraversable.Compat.Repl.Batteries
    Data.Bits.Compat Data.Bits.Compat.Repl.Batteries Data.Bool.Compat
    Data.Bool.Compat.Repl.Batteries Data.Complex.Compat
    Data.Complex.Compat.Repl.Batteries Data.Either.Compat
    Data.Either.Compat.Repl.Batteries Data.Foldable.Compat
    Data.Foldable.Compat.Repl.Batteries Data.Function.Compat
    Data.Function.Compat.Repl.Batteries Data.Functor.Compat
    Data.Functor.Compat.Repl.Batteries Data.Functor.Compose.Compat
    Data.Functor.Compose.Compat.Repl.Batteries
    Data.Functor.Const.Compat Data.Functor.Const.Compat.Repl.Batteries
    Data.Functor.Identity.Compat
    Data.Functor.Identity.Compat.Repl.Batteries
    Data.Functor.Product.Compat
    Data.Functor.Product.Compat.Repl.Batteries Data.Functor.Sum.Compat
    Data.Functor.Sum.Compat.Repl.Batteries Data.IORef.Compat
    Data.IORef.Compat.Repl.Batteries Data.List.Compat
    Data.List.Compat.Repl.Batteries Data.List.NonEmpty.Compat
    Data.List.NonEmpty.Compat.Repl.Batteries Data.Monoid.Compat
    Data.Monoid.Compat.Repl.Batteries Data.Proxy.Compat
    Data.Proxy.Compat.Repl.Batteries Data.Ratio.Compat
    Data.Ratio.Compat.Repl.Batteries Data.STRef.Compat
    Data.STRef.Compat.Repl.Batteries Data.Semigroup.Compat
    Data.Semigroup.Compat.Repl.Batteries Data.String.Compat
    Data.String.Compat.Repl.Batteries Data.Type.Coercion.Compat
    Data.Type.Coercion.Compat.Repl.Batteries Data.Version.Compat
    Data.Version.Compat.Repl.Batteries Data.Void.Compat
    Data.Void.Compat.Repl.Batteries Data.Word.Compat
    Data.Word.Compat.Repl.Batteries Debug.Trace.Compat
    Debug.Trace.Compat.Repl.Batteries Foreign.Compat
    Foreign.Compat.Repl.Batteries Foreign.ForeignPtr.Compat
    Foreign.ForeignPtr.Compat.Repl.Batteries
    Foreign.ForeignPtr.Safe.Compat
    Foreign.ForeignPtr.Safe.Compat.Repl.Batteries
    Foreign.ForeignPtr.Unsafe.Compat
    Foreign.ForeignPtr.Unsafe.Compat.Repl.Batteries
    Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Alloc.Compat.Repl.Batteries
    Foreign.Marshal.Array.Compat
    Foreign.Marshal.Array.Compat.Repl.Batteries Foreign.Marshal.Compat
    Foreign.Marshal.Compat.Repl.Batteries Foreign.Marshal.Safe.Compat
    Foreign.Marshal.Safe.Compat.Repl.Batteries
    Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Unsafe.Compat.Repl.Batteries
    Foreign.Marshal.Utils.Compat
    Foreign.Marshal.Utils.Compat.Repl.Batteries Numeric.Compat
    Numeric.Compat.Repl.Batteries Numeric.Natural.Compat
    Numeric.Natural.Compat.Repl.Batteries Prelude.Compat
    Prelude.Compat.Repl.Batteries System.Environment.Compat
    System.Environment.Compat.Repl.Batteries System.Exit.Compat
    System.Exit.Compat.Repl.Batteries System.IO.Unsafe.Compat
    System.IO.Unsafe.Compat.Repl.Batteries Text.Read.Compat
    Text.Read.Compat.Repl.Batteries Type.Reflection.Compat
    Type.Reflection.Compat.Repl.Batteries
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-compat-batteries-0.10.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-compat-batteries-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/base-compat-batteries-0.10.1
hs-libraries: HSbase-compat-batteries-0.10.1-LG7t1c0cCz36PTZWZEdTpV
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
haddock-interfaces: /usr/share/doc/haskell-base-compat-batteries/html/base-compat-batteries.haddock
haddock-html: /usr/share/doc/haskell-base-compat-batteries/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-compat-batteries-0.10.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-compat-batteries.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-compat-batteries
version: 0.10.1
id: base-compat-batteries-0.10.1-6mL9vKqgPYSLblr8bIxFdw
key: base-compat-batteries-0.10.1-6mL9vKqgPYSLblr8bIxFdw
license: MIT
copyright: (c) 2012-2018 Simon Hengel,
           (c) 2014-2018 João Cristóvão,
           (c) 2015-2018 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
synopsis: base-compat with extra batteries
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.
    .
    This package provides the same API as the
    @<http://hackage.haskell.org/package/base-compat base-compat>@
    library, but depends on compatibility packages
    (such as @semigroups@) to offer a wider support window than
    @base-compat@, which has no dependencies. Most of the modules
    in this library have the same names as in @base-compat@
    to make it easier to switch between the two. There also exist
    versions of each module with the suffix @.Repl.Batteries@,
    which are distinct from anything in @base-compat@, to allow
    for easier use in GHCi.
    .
    See
    @<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown#dependencies here>@
    for a more comprehensive list of differences between
    @base-compat@ and @base-compat-batteries@.
category: Compatibility
abi: b10324adbabb2cf37250d38523f4f712
exposed: True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.Compat.Repl.Batteries
    Control.Concurrent.MVar.Compat
    Control.Concurrent.MVar.Compat.Repl.Batteries Control.Monad.Compat
    Control.Monad.Compat.Repl.Batteries Control.Monad.Fail.Compat
    Control.Monad.Fail.Compat.Repl.Batteries
    Control.Monad.IO.Class.Compat
    Control.Monad.IO.Class.Compat.Repl.Batteries
    Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Lazy.Unsafe.Compat.Repl.Batteries
    Control.Monad.ST.Unsafe.Compat
    Control.Monad.ST.Unsafe.Compat.Repl.Batteries
    Data.Bifoldable.Compat Data.Bifoldable.Compat.Repl.Batteries
    Data.Bifunctor.Compat Data.Bifunctor.Compat.Repl.Batteries
    Data.Bitraversable.Compat Data.Bitraversable.Compat.Repl.Batteries
    Data.Bits.Compat Data.Bits.Compat.Repl.Batteries Data.Bool.Compat
    Data.Bool.Compat.Repl.Batteries Data.Complex.Compat
    Data.Complex.Compat.Repl.Batteries Data.Either.Compat
    Data.Either.Compat.Repl.Batteries Data.Foldable.Compat
    Data.Foldable.Compat.Repl.Batteries Data.Function.Compat
    Data.Function.Compat.Repl.Batteries Data.Functor.Compat
    Data.Functor.Compat.Repl.Batteries Data.Functor.Compose.Compat
    Data.Functor.Compose.Compat.Repl.Batteries
    Data.Functor.Const.Compat Data.Functor.Const.Compat.Repl.Batteries
    Data.Functor.Identity.Compat
    Data.Functor.Identity.Compat.Repl.Batteries
    Data.Functor.Product.Compat
    Data.Functor.Product.Compat.Repl.Batteries Data.Functor.Sum.Compat
    Data.Functor.Sum.Compat.Repl.Batteries Data.IORef.Compat
    Data.IORef.Compat.Repl.Batteries Data.List.Compat
    Data.List.Compat.Repl.Batteries Data.List.NonEmpty.Compat
    Data.List.NonEmpty.Compat.Repl.Batteries Data.Monoid.Compat
    Data.Monoid.Compat.Repl.Batteries Data.Proxy.Compat
    Data.Proxy.Compat.Repl.Batteries Data.Ratio.Compat
    Data.Ratio.Compat.Repl.Batteries Data.STRef.Compat
    Data.STRef.Compat.Repl.Batteries Data.Semigroup.Compat
    Data.Semigroup.Compat.Repl.Batteries Data.String.Compat
    Data.String.Compat.Repl.Batteries Data.Type.Coercion.Compat
    Data.Type.Coercion.Compat.Repl.Batteries Data.Version.Compat
    Data.Version.Compat.Repl.Batteries Data.Void.Compat
    Data.Void.Compat.Repl.Batteries Data.Word.Compat
    Data.Word.Compat.Repl.Batteries Debug.Trace.Compat
    Debug.Trace.Compat.Repl.Batteries Foreign.Compat
    Foreign.Compat.Repl.Batteries Foreign.ForeignPtr.Compat
    Foreign.ForeignPtr.Compat.Repl.Batteries
    Foreign.ForeignPtr.Safe.Compat
    Foreign.ForeignPtr.Safe.Compat.Repl.Batteries
    Foreign.ForeignPtr.Unsafe.Compat
    Foreign.ForeignPtr.Unsafe.Compat.Repl.Batteries
    Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Alloc.Compat.Repl.Batteries
    Foreign.Marshal.Array.Compat
    Foreign.Marshal.Array.Compat.Repl.Batteries Foreign.Marshal.Compat
    Foreign.Marshal.Compat.Repl.Batteries Foreign.Marshal.Safe.Compat
    Foreign.Marshal.Safe.Compat.Repl.Batteries
    Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Unsafe.Compat.Repl.Batteries
    Foreign.Marshal.Utils.Compat
    Foreign.Marshal.Utils.Compat.Repl.Batteries Numeric.Compat
    Numeric.Compat.Repl.Batteries Numeric.Natural.Compat
    Numeric.Natural.Compat.Repl.Batteries Prelude.Compat
    Prelude.Compat.Repl.Batteries System.Environment.Compat
    System.Environment.Compat.Repl.Batteries System.Exit.Compat
    System.Exit.Compat.Repl.Batteries System.IO.Unsafe.Compat
    System.IO.Unsafe.Compat.Repl.Batteries Text.Read.Compat
    Text.Read.Compat.Repl.Batteries Type.Reflection.Compat
    Type.Reflection.Compat.Repl.Batteries
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-compat-batteries-0.10.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-compat-batteries-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/base-compat-batteries-0.10.1
hs-libraries: HSbase-compat-batteries-0.10.1-6mL9vKqgPYSLblr8bIxFdw
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
haddock-interfaces: /usr/share/doc/haskell-base-compat-batteries/html/base-compat-batteries.haddock
haddock-html: /usr/share/doc/haskell-base-compat-batteries/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
